# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   pythonProject
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023/8/5 9:57
# Description:
# ---------------------------------------------------------------------------
"""
读取excel文件的步骤
    一：构造方法
        1.获取excel文件的路径
        2.获取表名
        3.打开工作簿
        4.打开工作表
        5.获取json文件的值
    二：方法
        1.先对表中所有的数据提取出来进行格式处理，如果为空返回None，如果有空格取消空格
        2，分别取出对应列的数据
"""
import openpyxl
from openpyxl.utils import get_column_letter
from interface_接口优化2.data_extraction.read_ini import ReadIni
from interface_接口优化2.data_extraction.read_json import read_json


class ReadExcel:

    # 读取excel表中的文件，获取json文件的值
    def __init__(self):
        self.read_ini = ReadIni()
        self.case_json_data = read_json(self.read_ini.read_file("case"))
        self.expect_json_data = read_json(self.read_ini.read_file("expect"))
        self.sql_json_data = read_json(self.read_ini.read_file("sql"))

        excel_path = self.read_ini.read_file("excel")
        excel_sheet = self.read_ini.read_sheet("sheet")
        self.wb = openpyxl.load_workbook(excel_path)
        self.ws = self.wb[excel_sheet]

    # 获取所有的单元格数据，如果为空返回None，如果有空格取消空格
    def data_process(self, column, row):
        if self.ws[str(column)+str(row)].value is None:
            return None
        elif self.ws[str(column)+str(row)].value.strip():
            return self.ws[str(column)+str(row)].value.strip()

    # 根据首行的内容获取对应的列号
    def get_name(self, name):
        for i in range(1, self.ws.max_column+1):
            if self.ws[get_column_letter(i) + str(1)].value == name:
                return get_column_letter(i)

    # 获取模块名称的值
    def get_mokuai(self, row):
        return self.data_process(self.get_name('模块名称'), row)

    def get_jk(self, row):
        return self.data_process(self.get_name('接口名称'), row)

    # 获取用例标题
    def get_title(self, row):
        return self.data_process(self.get_name('标题'), row)

    # 获取用例级别
    def get_level(self, row):
        return self.data_process(self.get_name('用例等级'), row)

    def get_method(self, row):
        return self.data_process(self.get_name('请求方法'), row)

    def get_url(self, row):
        host = self.read_ini.read_host("test_bpm")
        ulr = self.data_process(self.get_name('请求路径'), row)
        return host + ulr

    def get_mime(self, row):
        if self.data_process(self.get_name('媒体类型'), row):
            return self.data_process(self.get_name('媒体类型'), row).lower()

    # 获取excel表中关键字对应json文件用例数据的值
    def get_case_data(self, row):
        if self.data_process(self.get_name('用例数据'), row) is None:
            return None
        elif self.data_process(self.get_name('用例数据'), row):
            mokuai_name = self.get_mokuai(row)
            jk_name = self.get_jk(row)
            data = self.case_json_data[mokuai_name][jk_name][self.data_process(self.get_name('用例数据'), row)]
            return data

    # 获取excel表中关键字对应json文件期望数据的值
    def get_expect(self, row):
        if self.data_process(self.get_name("期望数据"), row) is None:
            return None
        elif self.data_process(self.get_name("期望数据"), row):
            mokuai_name = self.get_mokuai(row)
            jk_name = self.get_jk(row)
            expect_data = self.expect_json_data[mokuai_name][jk_name][self.data_process(self.get_name("期望数据"), row)]
            return expect_data

    # 获取sql语句的类型的值
    def get_sql_type(self, row):
        sql_type = self.data_process(self.get_name('SQL语句的类型'), row)
        if sql_type:
            return sql_type.lower()

    # 根据excel表的值获取存放在json文件中的sql语句
    def get_sql(self, row):
        sql_name = self.data_process(self.get_name('SQL语句'), row)
        if sql_name is None:
            return None
        elif sql_name.lower():
            mokuai_name = self.get_mokuai(row)
            jk_name = self.get_jk(row)
            sql_data = self.sql_json_data[mokuai_name][jk_name][sql_name]
            return sql_data

    # 根据表首行对应的列号获取更新的key的值
    def get_update_key(self, row):
        return self.data_process(self.get_name('更新的key'), row)

    # 将获取的值根据行号存放到一个二维列表中
    def all_data(self):
        lists_data = []
        for row in range(2, self.ws.max_row+1):
            mokuai_data = self.get_mokuai(row)
            jk_data = self.get_jk(row)
            title_data = self.get_title(row)
            level_data = self.get_level(row)
            method_data = self.get_method(row)
            mime_data = self.get_mime(row)
            url_data = self.get_url(row)
            case_data = self.get_case_data(row)
            expect_data = self.get_expect(row)
            sql_type = self.get_sql_type(row)
            sql_data = self.get_sql(row)
            update_key = self.get_update_key(row)
            lists_data.append([mokuai_data, jk_data, title_data, level_data, method_data, mime_data, url_data, case_data, expect_data, sql_type, sql_data, update_key])
        return lists_data


if __name__ == '__main__':
    read_excel = ReadExcel()
    print(read_excel.all_data())






